@@ -6,30 +6,26 @@
  *  B U G S - LIBRARY
  *
  *  DYNAMIC CRYPTOGRAPHY ALGORITHM
- *  Version 4.0.0 - "ARMISTICE"
- *  19 November 2000
+ *  Version 4.1.0 - "IBIZA"
+ *  26 July 2002 
  *
  *  -> generate passwd
  *  -> crypt file
  *  -> crypt stream
  *  -> make secure multi-users programms
  *
- *   Created by MARTINEZ Sylvain
+ *   Created by Sylvain MARTINEZ
  *
- *   Based on the BUGS crypt's algorithm of MARTINEZ Sylvain
+ *   Based on the BUGS crypt's algorithm of Sylvain Martinez
  *   (Big and Usefull Great Security)
  *
- *   UNIX Security Administrator (City, London, UK)
- *   Passion: Cryptology and Network Security
- *   emails: martinez@encryptsolutions.com
- *	     bugs@bcrypt.com
- *	     martinez@asi.fr
- *           sylvain.martinez@netcourrier.com
- *   BUGS Products URL	: http://www.bcrypt.com
- *   BUGS Company URL 	: http://www.encryptsolutions.com
- *   Personal URL     	: http://www.asi.fr/~martinez
+ *   Infrastructure Security Specialist (London, UK)
+ *   Main Interests: Cryptogaphy, Network Security and Surfing!
+ *   emails: bugs_contact@encryptsolutions.com
+ *           bugs_contact@bcrypt.com
+ *   BUGS PROJECT URL   : http://www.encryptsolutions.com
  *
- *  Copyright 1996-2000 MARTINEZ Sylvain
+ *  Copyright 1996-2003 Sylvain MARTINEZ
  *  THIS IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY IT UNDER
  *  THE TERMS OF THE GNU GENERAL PUBLIC LICENSE, see the file COPYING.
  */
@@ -42,6 +38,7 @@
 #include "../../include/misc.h"
 #include "../../include/main.h"  
 #include "../../include/utils.h"  
+#include "../../include/fpos_t.h"
 
 /*
  * === TEST PASSWD FUNCTION ===
@@ -899,6 +896,16 @@ bcrypt_delete_passwd
 
  fgetpos(file_old, &pos_old);
 
+#if _NEWFPOS_T == 1
+ while (pos_old.__pos < pos.__pos)
+  {
+   fread (var->name, varinit->USER_LENGTH, 1, file_old);
+   fread (var->pass, varinit->NB_CHAR, 1, file_old);
+   fwrite(var->name, varinit->USER_LENGTH, 1, file_s);
+   fwrite(var->pass, varinit->NB_CHAR, 1, file_s);
+   fgetpos (file_old, &pos_old);
+  }
+#else
  while (pos_old < pos)
   {
    fread (var->name, varinit->USER_LENGTH, 1, file_old);
@@ -907,8 +914,14 @@ bcrypt_delete_passwd
    fwrite(var->pass, varinit->NB_CHAR, 1, file_s);
    fgetpos (file_old, &pos_old);
   }
+#endif
 
+#if _NEWFPOS_T == 1
+ pos_old.__pos = pos_old.__pos + varinit->USER_LENGTH + varinit->NB_CHAR;
+#else
  pos_old = pos_old + varinit->USER_LENGTH + varinit->NB_CHAR;
+#endif
+
  fsetpos(file_old, &pos_old);
 
  fread (var->name, varinit->USER_LENGTH, 1, file_old);
