@@ -6,30 +6,26 @@
  *  B U G S - LIBRARY
  *
  *  DYNAMIC CRYPTOGRAPHY ALGORITHM
- *  Version 4.0.0 - "ARMISTICE"
- *  19 November 2000
+ *  Version 4.1.0 - "IBIZA"
+ *  26 July 2002 
  *
  *  -> generate passwd
  *  -> crypt file
  *  -> crypt stream
  *  -> make secure multi-users programms
  *
- *   Created by MARTINEZ Sylvain
+ *   Created by Sylvain MARTINEZ
  *
- *   Based on the BUGS crypt's algorithm of MARTINEZ Sylvain
+ *   Based on the BUGS crypt's algorithm of Sylvain Martinez
  *   (Big and Usefull Great Security)
  *
- *   UNIX Security Administrator (City, London, UK)
- *   Passion: Cryptology and Network Security
- *   emails: martinez@encryptsolutions.com
- *	     bugs@bcrypt.com
- *	     martinez@asi.fr
- *           sylvain.martinez@netcourrier.com
- *   BUGS Products URL	: http://www.bcrypt.com
- *   BUGS Company URL 	: http://www.encryptsolutions.com
- *   Personal URL     	: http://www.asi.fr/~martinez
+ *   Infrastructure Security Specialist (London, UK)
+ *   Main Interests: Cryptogaphy, Network Security and Surfing!
+ *   emails: bugs_contact@encryptsolutions.com
+ *           bugs_contact@bcrypt.com
+ *   BUGS PROJECT URL   : http://www.encryptsolutions.com
  *
- *  Copyright 1996-2000 MARTINEZ Sylvain
+ *  Copyright 1996-2003 Sylvain MARTINEZ
  *  THIS IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY IT UNDER
  *  THE TERMS OF THE GNU GENERAL PUBLIC LICENSE, see the file COPYING.
  */
